@@ -29,7 +29,7 @@ classifier = pipeline('text-classification', model=model, tokenizer=tokenizer) #
 #%%
 
 def load_embeddings(path):
-    return pd.read_csv(path + '\\data\\embeddings.csv')
+    return pd.read_csv(path + '/data/embeddings.csv')
 
 def predict(text_input):
     #running the classification model to predict the classes
